:mod:`art.detection`
====================
.. automodule:: art.detection

Binary Input Detector
---------------------
.. autoclass:: BinaryInputDetector
   :members:

Binary Activation Detector
--------------------------
.. autoclass:: BinaryActivationDetector
   :members:

:mod:`art.detection.subsetscanning`
===================================
.. automodule:: art.detection.subsetscanning

Subset Scanning Detector
------------------------
.. autoclass:: SubsetScanningDetector
   :members:
